@@ -1,9 +1,9 @@
 package Test::Smoke::BuildCFG;
 use strict;
 
-# $Id: BuildCFG.pm 484 2003-10-20 05:46:22Z abeltje $
+# $Id: BuildCFG.pm 764 2004-10-17 18:25:28Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.005';
+$VERSION = '0.008';
 
 use Cwd;
 use File::Spec;
@@ -365,6 +365,28 @@ sub policy_targets {
     return @targets;
 }
 
+=item as_string
+
+Return the parsed configuration as a string.
+
+=cut
+
+sub as_string {
+    my $self = shift;
+    my @sections;
+    for my $section ( @{ $self->{_sections} } ) {
+        if ( UNIVERSAL::isa( $section, 'ARRAY' ) ) {
+            push @sections, $section;
+        } elsif ( UNIVERSAL::isa( $section, 'HASH' ) ) {
+            push @sections, [
+                "/$section->{policy_target}/",
+                @{ $section->{args} },
+            ];
+        }
+    }
+    return join "=\n", map join( "\n", @$_, "" ) => @sections;
+}
+
 =item __get_smoked_configs( $logfile )
 
 Parse the logfile and return a hash(ref) of already processed
@@ -418,6 +440,17 @@ sub default_buildcfg() {
 __EOCONFIG__
 }
 
+=item new_configuration( $config )
+
+A wrapper around C<< Test::Smoke::BuildCFG::Config->new() >> so the
+object is accessible from outside this package.
+
+=cut
+
+sub new_configuration {
+    return Test::Smoke::BuildCFG::Config->new( @_ );
+}
+
 1;
 
 =back
@@ -427,7 +460,7 @@ __EOCONFIG__
 package Test::Smoke::BuildCFG::Config;
 
 use overload
-    '""'     => sub { $_[0]->[0] },
+    '""'     => sub { $_[0]->[0] || "" },
     fallback => 1;
 
 use Text::ParseWords qw( quotewords );
@@ -524,9 +557,13 @@ Create a hash with all the build arguments as keys.
 sub _split_args {
     my $self = shift;
 
+    my $i = 0;
     $self->[2] = {
-        map { ( $_ => 1 ) } quotewords( '\s+', 1, $self->[0] )
+        map { ( $_ => $i++ ) } quotewords( '\s+', 1, $self->[0] )
     };
+    $self->[0] = join( " ", sort {
+        $self->[2]{ $a } <=> $self->[2]{ $b }
+    } keys %{ $self->[2] } ) || "";
 }
 
 =item $buildcfg->has_arg( $arg[,...] )
@@ -591,6 +628,42 @@ sub args_eq {
     return (@left || keys %copy) ? 0 : 1;
 }
 
+=item rm_arg( $arg[,..] )
+
+Simply remove the argument(s) from the list and recreate the arguments
+line.
+
+=cut
+
+sub rm_arg {
+    my $self = shift;
+
+    foreach my $arg ( @_ ) {
+        exists $self->[2]{ $arg } and delete $self->[2]{ $arg };
+    }
+    $self->[0] = join( " ", sort {
+        $self->[2]{ $a } <=> $self->[2]{ $b }
+    } keys %{ $self->[2] } ) || "";
+}
+
+=item $config->vms
+
+Redo the the commandline switches in a VMSish way.
+
+=cut
+
+sub vms {
+    my $self = shift;
+
+    return join( " ", map {
+	tr/"'//d;
+        s/^-//;
+        qq/-"$_"/;
+    } sort {
+        $self->[2]{ $a } <=> $self->[2]{ $b }
+    } keys %{ $self->[2] } ) || "";
+}
+
 1;
 
 =back
