@@ -1,9 +1,9 @@
 package Test::Smoke::Reporter;
 use strict;
 
-# $Id: Reporter.pm 870 2005-07-21 16:11:53Z abeltje $
+# $Id: Reporter.pm 894 2005-07-31 15:44:42Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.022';
+$VERSION = '0.026';
 
 use Cwd;
 use File::Spec::Functions;
@@ -11,7 +11,8 @@ require File::Path;
 use Text::ParseWords;
 require Test::Smoke;
 use Test::Smoke::SysInfo;
-use Test::Smoke::Util qw( grepccmsg get_smoked_Config time_in_hhmm );
+use Test::Smoke::Util qw( grepccmsg get_smoked_Config
+                          time_in_hhmm get_local_patches );
 
 my %CONFIG = (
     df_ddir       => curdir(),
@@ -485,6 +486,8 @@ sub report {
     $report .= $self->letter_legend . "\n";
     $report .= $self->smoke_matrix . $self->bldenv_legend;
 
+    $report .= $self->registered_patches;
+
     $report .= "\nFailures: (common-args) $self->{_rpt}{common_args}\n"
             .  $self->failures if $self->has_test_failures;
     $report .= "\n" . $self->mani_fail           if $self->has_mani_failures;
@@ -522,6 +525,22 @@ sub ccinfo {
     return $cinfo;
 }
 
+=item $reporter->registered_patches()
+
+Return a section with the locally applied patches (from patchlevel.h).
+
+=cut
+
+sub registered_patches {
+    my $self = shift;
+
+    my @lpatches = get_local_patches( $self->{ddir}, $self->{v} );
+    @lpatches or return "";
+
+    my $list = join "\n", map "    $_" => @lpatches;
+    return "Locally applied patches:\n$list\n";
+}
+
 =item $reporter->ccmessages( )
 
 Use a port of Jarkko's F<grepccerr> script to report the compiler messages.
@@ -534,7 +553,7 @@ sub ccmessages {
     $ccinfo =~ s/^(.+)\s+version\s+.+/$1/;
 
     $^O =~ /^(?:linux|.*bsd.*|darwin)/ and $ccinfo = 'gcc';
-    my $cc = $ccinfo eq 'gcc' ? 'gcc' : $^O;
+    my $cc = $ccinfo =~ /(gcc|bcc32)/ ? $1 : $^O;
 
     $self->{v} and print "Looking for cc messages: '$cc'\n";
     my $errors = grepccmsg( $cc, $self->{lfile}, $self->{v} ) || [ ];
