@@ -1,9 +1,9 @@
 package Test::Smoke::SysInfo;
 use strict;
 
-# $Id: SysInfo.pm 860 2005-05-28 00:27:23Z abeltje $
+# $Id: SysInfo.pm 911 2005-09-10 22:48:21Z abeltje $
 use vars qw( $VERSION @EXPORT_OK );
-$VERSION = '0.025';
+$VERSION = '0.027';
 
 use base 'Exporter';
 @EXPORT_OK = qw( &sysinfo &tsuname );
@@ -129,7 +129,7 @@ sub __get_os {
         };
         $chk_os =~ /linux/i && do {
             my $dist_re = '[-_](?:release|version)\b';
-            my( $distro ) = grep /$dist_re/ => glob( '/etc/*' );
+            my( $distro ) = grep /$dist_re/ && !/\blsb-/ => glob( '/etc/*' );
             last MOREOS unless $distro;
             $distro =~ s|^/etc/||;
             $distro =~ s/$dist_re//i;
@@ -551,10 +551,8 @@ Use L<Win32::TieRegistry> if available to get better information.
 =cut
 
 sub Windows {
+    my( $cpu_type, $cpu, $ncpu );
 
-    my $cpu_type = $ENV{PROCESSOR_ARCHITECTURE};
-    my $cpu      = $ENV{PROCESSOR_IDENTIFIER};
-    my $ncpu     = $ENV{NUMBER_OF_PROCESSORS};
     eval { require Win32::TieRegistry };
     unless ( $@ ) {
         Win32::TieRegistry->import();
@@ -574,9 +572,9 @@ sub Windows {
     }
 
     return {
-        _cpu_type => $cpu_type,
-        _cpu      => $cpu,
-        _ncpu     => $ncpu,
+        _cpu_type => ( $cpu_type || $ENV{PROCESSOR_ARCHITECTURE} ),
+        _cpu      => ( $cpu || $ENV{PROCESSOR_IDENTIFIER} ),
+        _ncpu     => ( $ncpu || $ENV{NUMBER_OF_PROCESSORS} ),
         _host     => __get_hostname(),
         _os       => __get_os(),
     };
