@@ -2,9 +2,9 @@
 use strict;
 $| = 1;
 
-# $Id: synctree.pl 280 2003-07-28 20:01:35Z abeltje $
+# $Id: synctree.pl 809 2004-12-03 11:14:47Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.009';
+$VERSION = '0.011';
 
 use File::Spec;
 use FindBin;
@@ -12,6 +12,7 @@ use lib File::Spec->catdir( $FindBin::Bin, 'lib' );
 use lib $FindBin::Bin;
 use Test::Smoke;
 use Test::Smoke::Syncer;
+use Test::Smoke::Util qw( do_pod2usage );
 
 use Getopt::Long;
 my %opt = (
@@ -26,7 +27,7 @@ my %opt = (
 
 my $defaults = Test::Smoke::Syncer->config( 'all_defaults' );
 
-my %valid_type = map { $_ => 1 } qw( rsync snapshot copy hardlink forest );
+my %valid_type = map { $_ => 1 } qw( rsync snapshot copy hardlink forest ftp );
 
 =head1 NAME
 
@@ -106,6 +107,7 @@ This is a small front-end for L<Test::Smoke::Syncer>.
 
 =cut
 
+my $myusage = "Usage: $0 -t rsync -d <destdir>";
 GetOptions( \%opt,
     'type|t=s', 'ddir|d=s', 'v|verbose=i',
 
@@ -121,10 +123,10 @@ GetOptions( \%opt,
     'help|h', 'man|m',
 
     'config|c:s',
-) or do_pod2usage( verbose => 1 );
+) or do_pod2usage( verbose => 1, myusage => $myusage );
 
-$opt{ man} and do_pod2usage( verbose => 2, exitval => 0 );
-$opt{help} and do_pod2usage( verbose => 1, exitval => 0 );
+$opt{ man} and do_pod2usage( verbose => 2, exitval => 0, myusage => $myusage );
+$opt{help} and do_pod2usage( verbose => 1, exitval => 0, myusage => $myusage );
 
 if ( defined $opt{config} ) {
     $opt{config} eq "" and $opt{config} = 'smokecurrent_config';
@@ -164,23 +166,6 @@ $patchlevel = $syncer->sync;
 
 $opt{v} and print "$opt{ddir} now up to patchlevel $patchlevel\n";
 
-sub do_pod2usage {
-    eval { require Pod::Usage };
-    if ( $@ ) {
-        print <<EO_MSG;
-Usage: $0 -t <type> -d <directory> [options]
-
-Use 'perldoc $0' for the documentation.
-Please install 'Pod::Usage' for easy access to the docs.
-
-EO_MSG
-        my %p2u_opt = @_;
-        exit( exists $p2u_opt{exitval} ? $p2u_opt{exitval} : 1 );
-    } else {
-        Pod::Usage::pod2usage( @_ );
-    }
-}
-
 =head1 SEE ALSO
 
 L<perlhack/"Keeping in sync">, L<Test::Smoke::Syncer>
